.. Shared CMake submodule documentation master file, created by
   sphinx-quickstart on Wed Sep 27 13:16:53 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Shared CMake submodule
######################

This repository_ is meant to be used as a submodule for any project
from CNRS LAAS/HPP or JRL.

It factorizes CMake mechanisms to provide a uniform look'n feel for
all packages.

.. setmode:: user

Contents
#########

.. toctree::
   :maxdepth: 3

   /pages/base.rst
   /pages/cmake-packages.rst
   /pages/projects.rst
   /pages/dependencies.rst
   /pages/other.rst
   /pages/internal.rst
   /pages/developers.rst


Indices and tables
##################

* :ref:`genindex`
* :ref:`search`

.. * :ref:`modindex`
.. _repository: https://github.com/jrl-umi3218/jrl-cmakemodules
